==> igniteui-webcomponents-core-3.2.4.tgz: package/esm5/lib/WebNumberEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebNumberEventArgsDescription } from "./WebNumberEventArgsDescription";
/**
 * @hidden
 */
var WebNumberEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebNumberEventArgsDescriptionMetadata, _super);
    function WebNumberEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebNumberEventArgsDescriptionMetadata.b = function (a) {
        if (WebNumberEventArgsDescriptionMetadata.a == null) {
            WebNumberEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebNumberEventArgsDescriptionMetadata.c(WebNumberEventArgsDescriptionMetadata.a);
        }
        if (a.g(WebNumberEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(WebNumberEventArgsDescriptionMetadata.a);
    };
    WebNumberEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:NumberEventArgs");
        a.item("Detail", "Number:double");
    };
    WebNumberEventArgsDescriptionMetadata.d = function (a) {
        WebNumberEventArgsDescriptionMetadata.b(a);
        a.u("WebNumberEventArgs", function () { return new WebNumberEventArgsDescription(); });
        a.t("WebNumberEventArgs", WebNumberEventArgsDescriptionMetadata.a);
    };
    WebNumberEventArgsDescriptionMetadata.$t = markType(WebNumberEventArgsDescriptionMetadata, 'WebNumberEventArgsDescriptionMetadata');
    WebNumberEventArgsDescriptionMetadata.a = null;
    return WebNumberEventArgsDescriptionMetadata;
}(Base));
export { WebNumberEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/WebNumberEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebNumberEventArgsDescription } from "./WebNumberEventArgsDescription";
/**
 * @hidden
 */
var WebNumberEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebNumberEventArgsDescriptionMetadata, _super);
    function WebNumberEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebNumberEventArgsDescriptionMetadata.b = function (a) {
        if (WebNumberEventArgsDescriptionMetadata.a == null) {
            WebNumberEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebNumberEventArgsDescriptionMetadata.c(WebNumberEventArgsDescriptionMetadata.a);
        }
        if (a.j(WebNumberEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(WebNumberEventArgsDescriptionMetadata.a);
    };
    WebNumberEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:NumberEventArgs");
        a.item("Detail", "Number:double");
    };
    WebNumberEventArgsDescriptionMetadata.d = function (a) {
        WebNumberEventArgsDescriptionMetadata.b(a);
        a.aa("WebNumberEventArgs", function () { return new WebNumberEventArgsDescription(); });
        a.z("WebNumberEventArgs", WebNumberEventArgsDescriptionMetadata.a);
    };
    WebNumberEventArgsDescriptionMetadata.$t = markType(WebNumberEventArgsDescriptionMetadata, 'WebNumberEventArgsDescriptionMetadata');
    WebNumberEventArgsDescriptionMetadata.a = null;
    return WebNumberEventArgsDescriptionMetadata;
}(Base));
export { WebNumberEventArgsDescriptionMetadata };
